==> v1.0.5.zip: dees-comms/ts/dees-comms.classes.deescomms.ts <==
import { TypedRequest } from '@apiglobal/typedrequest';
import * as plugins from './dees-comms.plugins';

/**
 * a comm class for client side communication between workers and tabs.
 */
export class DeesComms {
  // sending messages
  private postChannel = new BroadcastChannel('dees-comms');
  public typedrouter = new plugins.typedrequest.TypedRouter();

  private subscriptionChannel = new BroadcastChannel('dees-comms');

  constructor() {
    this.subscriptionChannel.onmessage = (eventArg) => {
      const message = eventArg.data;
      console.log(JSON.stringify(message));
      this.typedrouter.routeAndAddResponse(message);
    };
  }

  /**
   * creates a typedrequest with this classes postMessage as postMethod
   */
  public createTypedRequest<T extends plugins.typedrequestInterfaces.ITypedRequest>(
    methodName: T['method']
  ): TypedRequest<T> {
    const typedrequest = new plugins.typedrequest.TypedRequest(
      async (messageArg) => {
        this.postMessage(messageArg);
      },
      methodName,
      this.typedrouter
    );
    return typedrequest;
  }

  /**
   * posts a typedrequestmessage
   */
  public async postMessage<T = plugins.typedrequestInterfaces.ITypedRequest>(
    messageArg: T
  ): Promise<void> {
    this.postChannel.postMessage(messageArg);
  }

  /**
   * subscribe to messages
   */
  public async createTypedHandler<T extends plugins.typedrequestInterfaces.ITypedRequest>(
    methodArg: T['method'],
    handlerFunction: plugins.typedrequest.THandlerFunction<T>
  ) {
    this.typedrouter.addTypedHandler(new plugins.typedrequest.TypedHandler<T>(methodArg, handlerFunction));
  }
}

==> v1.0.7.zip: dees-comms/ts/dees-comms.classes.deescomms.ts <==
import { TypedRequest } from '@apiglobal/typedrequest';
import * as plugins from './dees-comms.plugins';

let BroadcastChannel = globalThis.BroadcastChannel;
if (!BroadcastChannel) {
  BroadcastChannel = plugins.BroadCastChannelPolyfill as any;
}

/**
 * a comm class for client side communication between workers and tabs.
 */
export class DeesComms {
  // sending messages
  private postChannel = new BroadcastChannel('dees-comms');
  public typedrouter = new plugins.typedrequest.TypedRouter();

  private subscriptionChannel = new BroadcastChannel('dees-comms');

  constructor() {
    this.subscriptionChannel.onmessage = async (eventArg) => {
      const message = eventArg.data;
      console.log(JSON.stringify(message));
      const response = await this.typedrouter.routeAndAddResponse(message);
      if (response) {
        this.postMessage(response);
      }
    };
  }

  /**
   * creates a typedrequest with this classes postMessage as postMethod
   */
  public createTypedRequest<T extends plugins.typedrequestInterfaces.ITypedRequest>(
    methodName: T['method']
  ): TypedRequest<T> {
    const typedrequest = new plugins.typedrequest.TypedRequest(
      async (messageArg) => {
        this.postMessage(messageArg);
      },
      methodName,
      this.typedrouter
    );
    return typedrequest;
  }

  /**
   * posts a typedrequestmessage
   */
  public async postMessage<T = plugins.typedrequestInterfaces.ITypedRequest>(
    messageArg: T
  ): Promise<void> {
    this.postChannel.postMessage(messageArg);
  }

  /**
   * subscribe to messages
   */
  public async createTypedHandler<T extends plugins.typedrequestInterfaces.ITypedRequest>(
    methodArg: T['method'],
    handlerFunction: plugins.typedrequest.THandlerFunction<T>
  ) {
    this.typedrouter.addTypedHandler(new plugins.typedrequest.TypedHandler<T>(methodArg, handlerFunction));
  }
}
